@@ -5,8 +5,8 @@
 ;; Created: 2010
 ;; Keywords: languages
 ;; URL: https://github.com/openscad/emacs-scad-mode
-;; Package-Requires: ((emacs "28.1") (compat "30"))
-;; Version: 97.0
+;; Package-Requires: ((emacs "29.1") (compat "30"))
+;; Version: 98.0
 
 ;; This file is not part of GNU Emacs.
 
@@ -197,7 +197,7 @@ Options are .stl, .off, .amf, .3mf, .csg, .dxf, .svg, .pdf, .png,
 
 (defun scad-completion-at-point ()
   "Completion at point function."
-  (when-let (bounds (bounds-of-thing-at-point 'word))
+  (when-let* ((bounds (bounds-of-thing-at-point 'word)))
     (list (car bounds) (cdr bounds)
           scad-completions
           :exclusive 'no)))
@@ -300,7 +300,7 @@ Options are .stl, .off, .amf, .3mf, .csg, .dxf, .svg, .pdf, .png,
   (scad--preview-render))
 
 ;; Based on https://github.com/zk-phi/scad-preview
-(defun scad--preview-render (&rest _)
+(defun scad--preview-render (&optional _)
   "Render image from current buffer."
   (if (not (buffer-live-p scad--preview-buffer))
       (scad--preview-status "Dead")
@@ -321,7 +321,7 @@ Options are .stl, .off, .amf, .3mf, .csg, .dxf, .svg, .pdf, .png,
           ;; Setting the OPENSCADPATH to the current directory allows openscad to pick
           ;; up other local files with `include <file.scad>'.
           (("OPENSCADPATH"
-            (if-let ((path (getenv "OPENSCADPATH")))
+            (if-let* ((path (getenv "OPENSCADPATH")))
                 (concat default-directory path-separator path)
               default-directory)))
         (setq scad--preview-proc
@@ -406,10 +406,13 @@ Options are .stl, .off, .amf, .3mf, .csg, .dxf, .svg, .pdf, .png,
   (add-hook 'kill-buffer-hook #'scad--preview-kill nil 'local)
   (add-hook 'kill-buffer-hook #'scad--preview-delete nil 'local)
   (add-hook 'window-size-change-functions
-            (let ((buf (current-buffer)))
-              (lambda (_)
-                (with-current-buffer buf
-                  (scad--preview-render))))
+            ;; On Emacs 31 `window-size-change-functions' run in current buffer
+            (static-if (>= emacs-major-version 31)
+                #'scad--preview-render
+              (let ((buf (current-buffer)))
+                (lambda (_)
+                  (with-current-buffer buf
+                    (scad--preview-render)))))
             nil 'local))
 
 (defun scad-preview-projection ()
@@ -464,7 +467,7 @@ Options are .stl, .off, .amf, .3mf, .csg, .dxf, .svg, .pdf, .png,
         ;; Setting the OPENSCADPATH to the current directory allows openscad to pick
         ;; up other local files with `include <file.scad>'.
         (("OPENSCADPATH"
-          (if-let ((path (getenv "OPENSCADPATH")))
+          (if-let* ((path (getenv "OPENSCADPATH")))
               (concat default-directory path-separator path)
             default-directory)))
       (setq
